/**************************************************************************
 *
 * Copyright (c) 2015 MediaTek Inc. All Rights Reserved.
 * --------------------
 * This software is protected by copyright and the information contained
 * herein is confidential. The software may not be copied and the information
 * contained herein may not be used or disclosed except with the written
 * permission of MediaTek Inc.
 *
 ***************************************************************************/

precision mediump float;

/* Material uniforms */
uniform sampler2D u_m_diffuseTexture;
uniform sampler2D u_m_dataInfo;
uniform sampler2D u_m_freqTexture;
uniform vec4 u_m_diffuseColour;
uniform float u_m_opacity;
uniform float u_m_offset;
uniform float u_m_y_percent;
uniform float u_m_y_moveup;
uniform float u_m_usage;
uniform vec3 u_m_usage_xyz;
uniform vec3 u_m_colour;

uniform vec3 u_m_circle_height;

varying vec2 v_texcoord;      // Adjusted texture coordinate

// Y = 0.299 * R + 0.587 * G + 0.114 * B
const vec3 YUV = vec3(0.299, 0.587, 0.114);
const float Pi = 3.14159265358979323436;

void main() {
    gl_FragColor = u_m_diffuseColour * texture2D( u_m_diffuseTexture, v_texcoord );

    float value = (1.1111 * v_texcoord.x + u_m_offset);
    vec4 color = texture2D( u_m_dataInfo, vec2(value, 0.0) ) * u_m_y_percent;

    /**************** draw history ****************/
    // (1.0 - u_m_y_moveup - color.g) < v_texcoord.y
    float yfactor = smoothstep((1.0 - u_m_y_moveup - color.g), (1.0 - u_m_y_moveup - color.g) + 0.01, v_texcoord.y);
    gl_FragColor.rgb = mix(gl_FragColor.rgb, u_m_colour * 0.7, yfactor);

	vec2 coord = v_texcoord * 2.0 - 1.0;
	float len = length(coord);
	vec2 zero = vec2(0.0, 1.0);
	float ab = (zero.x * coord.x + zero.y * coord.y) / length(coord);
	float usage = acos(ab) / (Pi);
    usage = (coord.x >= 0.0) ? ((1.0 - usage) * 0.5 + 0.5) : (usage * 0.5);

    vec3 circle_colour = u_m_colour;
	/**************** circle line start ****************/
    float border = u_m_circle_height.z * u_m_circle_height.x;
    float base = u_m_circle_height.y * u_m_circle_height.x;
    //float edge = smoothstep(base - border, base, len) - smoothstep(base, base + border, len);
    float edge = smoothstep(base - border, base, len) - smoothstep(base + border, base + border * 2.6, len);

    // u_m_usage >= usage
    border = 8.0 / 360.0;
    float usage_edge = 1.0 - smoothstep(u_m_usage, u_m_usage + border, usage);
    edge = clamp(edge * usage_edge, 0.0, 1.0);

    gl_FragColor.rgb = mix(gl_FragColor.rgb, circle_colour, edge);
    gl_FragColor.a += edge;
    /**************** circle line End ****************/


    /**************** circle Point start *************/
    float len_target = length(coord.xy - u_m_usage_xyz.xy);
    float factor = clamp(smoothstep(0.0, (3.0 * u_m_circle_height.z * u_m_circle_height.x) , len_target), 0.0, 1.0);
    factor = 1.0 - pow(factor, 50.0);
    gl_FragColor.rgb = mix(gl_FragColor.rgb, clamp(circle_colour + YUV * 0.2, 0.0, 1.0), factor);
    gl_FragColor.a += factor;
    /**************** circle Point End ***************/


    // draw freq String
    vec4 freq = texture2D(u_m_freqTexture, v_texcoord);
    gl_FragColor.rgb = mix(gl_FragColor.rgb, freq.rgb, freq.a);


	gl_FragColor.a *= u_m_opacity;
}
